@@ -3,9 +3,11 @@ from __future__ import annotations
 import argparse
 import logging
 import sys
+from copy import deepcopy
 from functools import partial
 from pathlib import Path
 from types import TracebackType
+from typing import Any, Sequence
 
 import argcomplete
 from decli import cli
@@ -15,10 +17,72 @@ from commitizen.exceptions import (
     CommitizenException,
     ExitCode,
     ExpectedExit,
+    InvalidCommandArgumentError,
     NoCommandFoundError,
 )
 
 logger = logging.getLogger(__name__)
+
+
+class ParseKwargs(argparse.Action):
+    """
+    Parse arguments in the for `key=value`.
+
+    Quoted strings are automatically unquoted.
+    Can be submitted multiple times:
+
+    ex:
+        -k key=value -k double-quotes="value" -k single-quotes='value'
+
+        will result in
+
+        namespace["opt"] == {
+            "key": "value",
+            "double-quotes": "value",
+            "single-quotes": "value",
+        }
+    """
+
+    def __call__(
+        self,
+        parser: argparse.ArgumentParser,
+        namespace: argparse.Namespace,
+        kwarg: str | Sequence[Any] | None,
+        option_string: str | None = None,
+    ):
+        if not isinstance(kwarg, str):
+            return
+        if "=" not in kwarg:
+            raise InvalidCommandArgumentError(
+                f"Option {option_string} expect a key=value format"
+            )
+        kwargs = getattr(namespace, self.dest, None) or {}
+        key, value = kwarg.split("=", 1)
+        if not key:
+            raise InvalidCommandArgumentError(
+                f"Option {option_string} expect a key=value format"
+            )
+        kwargs[key] = value.strip("'\"")
+        setattr(namespace, self.dest, kwargs)
+
+
+tpl_arguments = (
+    {
+        "name": ["--template", "-t"],
+        "help": (
+            "changelog template file name "
+            "(relative to the current working directory)"
+        ),
+    },
+    {
+        "name": ["--extra", "-e"],
+        "action": ParseKwargs,
+        "dest": "extras",
+        "metavar": "EXTRA",
+        "help": "a changelog extra variable (in the form 'key=value')",
+    },
+)
+
 data = {
     "prog": "cz",
     "description": (
@@ -209,6 +273,11 @@ data = {
                         "default": None,
                         "help": "keep major version at zero, even for breaking changes",
                     },
+                    *deepcopy(tpl_arguments),
+                    {
+                        "name": "--file-name",
+                        "help": "file name of changelog (default: 'CHANGELOG.md')",
+                    },
                     {
                         "name": ["--prerelease-offset"],
                         "type": int,
@@ -298,6 +367,12 @@ data = {
                         "default": None,
                         "choices": version_schemes.KNOWN_SCHEMES,
                     },
+                    {
+                        "name": "--export-template",
+                        "default": None,
+                        "help": "Export the changelog template into this file instead of rendering it",
+                    },
+                    *deepcopy(tpl_arguments),
                 ],
             },
             {
@@ -441,7 +516,7 @@ def main():
 
     # This is for the command required constraint in 2.0
     try:
-        args = parser.parse_args()
+        args, unknown_args = parser.parse_known_args()
     except (TypeError, SystemExit) as e:
         # https://github.com/commitizen-tools/commitizen/issues/429
         # argparse raises TypeError when non exist command is provided on Python < 3.9
@@ -450,6 +525,28 @@ def main():
             raise NoCommandFoundError()
         raise e
 
+    arguments = vars(args)
+    if unknown_args:
+        # Raise error for extra-args without -- separation
+        if "--" not in unknown_args:
+            raise InvalidCommandArgumentError(
+                f"Invalid commitizen arguments were found: `{' '.join(unknown_args)}`. "
+                "Please use -- separator for extra git args"
+            )
+        # Raise error for extra-args before --
+        elif unknown_args[0] != "--":
+            pos = unknown_args.index("--")
+            raise InvalidCommandArgumentError(
+                f"Invalid commitizen arguments were found before -- separator: `{' '.join(unknown_args[:pos])}`. "
+            )
+        # Log warning for -- without any extra args
+        elif len(unknown_args) == 1:
+            logger.warning(
+                "\nWARN: Incomplete commit command: received -- separator without any following git arguments\n"
+            )
+        extra_args = " ".join(unknown_args[1:])
+        arguments["extra_cli_args"] = extra_args
+
     if args.name:
         conf.update({"name": args.name})
     elif not args.name and not conf.path:
@@ -465,7 +562,7 @@ def main():
         )
         sys.excepthook = no_raise_debug_excepthook
 
-    args.func(conf, vars(args))()
+    args.func(conf, arguments)()
 
 
 if __name__ == "__main__":
