@@ -22,6 +22,7 @@ from commitizen.exceptions import (
     NotAllowed,
     NoVersionSpecifiedError,
 )
+from commitizen.changelog_formats import get_changelog_format
 from commitizen.providers import get_provider
 from commitizen.version_schemes import InvalidVersion, get_version_scheme
 
@@ -51,6 +52,8 @@ class Bump:
                     "annotated_tag",
                     "major_version_zero",
                     "prerelease_offset",
+                    "template",
+                    "file_name",
                 ]
                 if arguments[key] is not None
             },
@@ -77,6 +80,17 @@ class Bump:
         self.scheme = get_version_scheme(
             self.config, arguments["version_scheme"] or deprecated_version_type
         )
+        self.file_name = arguments["file_name"] or self.config.settings.get(
+            "changelog_file"
+        )
+        self.changelog_format = get_changelog_format(self.config, self.file_name)
+
+        self.template = (
+            arguments["template"]
+            or self.config.settings.get("template")
+            or self.changelog_format.template
+        )
+        self.extras = arguments["extras"]
 
     def is_initial_tag(self, current_tag_version: str, is_yes: bool = False) -> bool:
         """Check if reading the whole git tree up to HEAD is needed."""
@@ -87,11 +101,9 @@ class Bump:
             else:
                 out.info(f"Tag {current_tag_version} could not be found. ")
                 out.info(
-                    (
-                        "Possible causes:\n"
-                        "- version in configuration is not the current version\n"
-                        "- tag_format is missing, check them using 'git tag --list'\n"
-                    )
+                    "Possible causes:\n"
+                    "- version in configuration is not the current version\n"
+                    "- tag_format is missing, check them using 'git tag --list'\n"
                 )
                 is_initial = questionary.confirm("Is this the first tag created?").ask()
         return is_initial
@@ -261,6 +273,8 @@ class Bump:
                     self.config,
                     {
                         "unreleased_version": new_tag_version,
+                        "template": self.template,
+                        "extras": self.extras,
                         "incremental": True,
                         "dry_run": True,
                     },
@@ -275,6 +289,9 @@ class Bump:
                     "unreleased_version": new_tag_version,
                     "incremental": True,
                     "dry_run": dry_run,
+                    "template": self.template,
+                    "extras": self.extras,
+                    "file_name": self.file_name,
                 },
             )
             changelog_cmd()
