@@ -98,7 +98,9 @@ def add(args: str = "") -> cmd.Command:
 
 
 def commit(
-    message: str, args: str = "", committer_date: str | None = None
+    message: str,
+    args: str = "",
+    committer_date: str | None = None,
 ) -> cmd.Command:
     f = NamedTemporaryFile("wb", delete=False)
     f.write(message.encode("utf-8"))
